div#buildBtns {
	position: absolute;
	top: 50px;
	left: 0px;
}

div#buildBtns:before, div#craftBtns:before, div#buyBtns:before {
	content: attr(data-legend);
	position: relative;
	top: -5px;
}

div#craftBtns {
	position: absolute;
	top: 50px;
	left: 150px;
}

div#buyBtns {
	position: absolute;
	top: 50px;
	left: 300px;
}

div#storesContainer {
	position: absolute;
	top: 0px;
	right: 0px;
}

div#stores:before, div#weapons:before {
	position: absolute;
	background: white;
	content: attr(data-legend);
	left: 8px;
	top: -13px;
}

div#stores {
	position: relative;
	z-index:10;
	border: 1px solid black;
	cursor: default;
	padding: 5px 10px;
	width: 200px;
}

div.storeRow {
	position: relative;
}

div#weapons {
	margin-top: 15px;
	position: relative;
	right: 0px;
	border: 1px solid black;
	cursor: default;
	padding: 5px 10px;
	width: 200px;
}
