div#village {
	position: absolute;
	top: 0px;
	right: 0px;
	border: 1px solid black;
	cursor: default;
	padding: 5px 10px;
	width: 200px;
}

div#population {
	position: absolute;
	top: -13px;
	right: 10px;
	background-color: white;
}

.noHuts #population {
	display: none;
}

div#village:before {
	position: absolute;
	background: white;
	content: attr(data-legend);
	left: 8px;
	top: -13px;
}

div#workers {
	position:absolute;
	top: -4px;
	left: 160px;
	width: 150px;
}

.workerRow > .row_val {
	position: relative;
	padding-right: 20px;
	-webkit-touch-callout: none;
	-webkit-user-select: none;
	-khtml-user-select: none;
	-moz-user-select: none;
	-ms-user-select: none;
	user-select: none;
}

.workerRow {
	position: relative;
	margin: 10px 0px;
	cursor: default;
}

.workerRow .tooltip {
	width: 150px;
}

div.storeRow div.tooltip {
	width: 160px;
}
