.button{width: 100px !important;}
#outsidePanel .button{width: 115px !important;}
.eventPanel .button {width: 122px !important;}
#lootButtons:before {
	content: "prendre :" !important;
}
#dropMenu:before {
	content: "déposer :" !important;
}
#hullRow {
    width: 80px !important;
}
div#workers {
    width: 160px !important;
}
div.button div.tooltip {
	width: 120px !important;
}
