var langs = {
	'cs':'czech',
	'de':'deutsch',
	'el':'ελληνικά',
	'en':'english',
	'eo':'esperanto',
	'es':'español',
	'fr':'français',
	'gl':'galego',
	'id':'bahasa indonesia',
	'it':'italiano',
	'lv':'latviešu valoda',
	'ja':'日本語',
	'ko':'한국어',
	'nb':'norsk',
	'pl':'polski',
	'lt_LT':'lietuvių',
	'pt':'português',
	'pt_br':'português (brasil)',
	'ru':'русский',
	'sv':'svenska',
	'th':'ไทย',
	'tr':'türkçe',
	'uk':'українська',
	'vi':'tiếng việt',
	'zh_cn':'简体中文',
	'zh_tw':'繁體中文'
};
