/**
 * Module that defines all audio files
 */
var AudioLibrary = {
    MUSIC_DUSTY_PATH: 'audio/dusty-path.flac',
    MUSIC_SILENT_FOREST: 'audio/silent-forest.flac',
    MUSIC_LONELY_HUT: 'audio/lonely-hut.flac',
    MUSIC_TINY_VILLAGE: 'audio/tiny-village.flac',
    MUSIC_MODEST_VILLAGE: 'audio/modest-village.flac',
    MUSIC_LARGE_VILLAGE: 'audio/large-village.flac',
    MUSIC_RAUCOUS_VILLAGE: 'audio/raucous-village.flac',
    MUSIC_FIRE_DEAD: 'audio/fire-dead.flac',
    MUSIC_FIRE_SMOLDERING: 'audio/fire-smoldering.flac',
    MUSIC_FIRE_FLICKERING: 'audio/fire-flickering.flac',
    MUSIC_FIRE_BURNING: 'audio/fire-burning.flac',
    MUSIC_FIRE_ROARING: 'audio/fire-roaring.flac',
    MUSIC_WORLD: 'audio/world.flac',
    MUSIC_SPACE: 'audio/space.flac',
    MUSIC_ENDING: 'audio/ending.flac',
    MUSIC_SHIP: 'audio/ship.flac',
    EVENT_NOMAD: 'audio/event-nomad.flac',
    EVENT_NOISES_OUTSIDE: 'audio/event-noises-outside.flac',
    EVENT_NOISES_INSIDE: 'audio/event-noises-inside.flac',
    EVENT_BEGGAR: 'audio/event-beggar.flac',
    EVENT_SHADY_BUILDER: 'audio/event-shady-builder.flac',
    EVENT_MYSTERIOUS_WANDERER: 'audio/event-mysterious-wanderer.flac',
    EVENT_SCOUT: 'audio/event-scout.flac',
    EVENT_WANDERING_MASTER: 'audio/event-wandering-master.flac',
    EVENT_SICK_MAN: 'audio/event-sick-man.flac',
    EVENT_RUINED_TRAP: 'audio/event-ruined-trap.flac',
    EVENT_HUT_FIRE: 'audio/event-hut-fire.flac',
    EVENT_SICKNESS: 'audio/event-sickness.flac',
    EVENT_PLAGUE: 'audio/event-plague.flac',
    EVENT_BEAST_ATTACK: 'audio/event-beast-attack.flac',
    EVENT_SOLDIER_ATTACK: 'audio/event-soldier-attack.flac',
    EVENT_THIEF: 'audio/event-thief.flac',
    LANDMARK_FRIENDLY_OUTPOST: 'audio/landmark-friendly-outpost.flac',
    LANDMARK_SWAMP: 'audio/landmark-swamp.flac',
    LANDMARK_CAVE: 'audio/landmark-cave.flac',
    LANDMARK_TOWN: 'audio/landmark-town.flac',
    LANDMARK_CITY: 'audio/landmark-city.flac',
    LANDMARK_HOUSE: 'audio/landmark-house.flac',
    LANDMARK_BATTLEFIELD: 'audio/landmark-battlefield.flac',
    LANDMARK_BOREHOLE: 'audio/landmark-borehole.flac',
    LANDMARK_CRASHED_SHIP: 'audio/landmark-crashed-ship.flac',
    LANDMARK_SULPHUR_MINE: 'audio/landmark-sulphurmine.flac',
    LANDMARK_COAL_MINE: 'audio/landmark-coalmine.flac',
    LANDMARK_IRON_MINE: 'audio/landmark-ironmine.flac',
    LANDMARK_DESTROYED_VILLAGE: 'audio/landmark-destroyed-village.flac',
    ENCOUNTER_TIER_1: 'audio/encounter-tier-1.flac',
    ENCOUNTER_TIER_2: 'audio/encounter-tier-2.flac',
    ENCOUNTER_TIER_3: 'audio/encounter-tier-3.flac',
    LIGHT_FIRE: 'audio/light-fire.flac',
    STOKE_FIRE: 'audio/stoke-fire.flac',
    BUILD: 'audio/build.flac',
    CRAFT: 'audio/craft.flac',
    BUY: 'audio/buy.flac',
    GATHER_WOOD: 'audio/gather-wood.flac',
    CHECK_TRAPS: 'audio/check-traps.flac',
    EMBARK: 'audio/embark.flac',
    FOOTSTEPS_1: 'audio/footsteps-1.flac',
    FOOTSTEPS_2: 'audio/footsteps-2.flac',
    FOOTSTEPS_3: 'audio/footsteps-3.flac',
    FOOTSTEPS_4: 'audio/footsteps-4.flac',
    FOOTSTEPS_5: 'audio/footsteps-5.flac',
    FOOTSTEPS_6: 'audio/footsteps-6.flac',
    EAT_MEAT: 'audio/eat-meat.flac',
    USE_MEDS: 'audio/use-meds.flac',
    WEAPON_UNARMED_1: 'audio/weapon-unarmed-1.flac',
    WEAPON_UNARMED_2: 'audio/weapon-unarmed-2.flac',
    WEAPON_UNARMED_3: 'audio/weapon-unarmed-3.flac',
    WEAPON_MELEE_1: 'audio/weapon-melee-1.flac',
    WEAPON_MELEE_2: 'audio/weapon-melee-2.flac',
    WEAPON_MELEE_3: 'audio/weapon-melee-3.flac',
    WEAPON_RANGED_1: 'audio/weapon-ranged-1.flac',
    WEAPON_RANGED_2: 'audio/weapon-ranged-2.flac',
    WEAPON_RANGED_3: 'audio/weapon-ranged-3.flac',
    DEATH: 'audio/death.flac',
    REINFORCE_HULL: 'audio/reinforce-hull.flac',
    UPGRADE_ENGINE: 'audio/upgrade-engine.flac',
    LIFT_OFF: 'audio/lift-off.flac',
    ASTEROID_HIT_1: 'audio/asteroid-hit-1.flac',
    ASTEROID_HIT_2: 'audio/asteroid-hit-2.flac',
    ASTEROID_HIT_3: 'audio/asteroid-hit-3.flac',
    ASTEROID_HIT_4: 'audio/asteroid-hit-4.flac',
    ASTEROID_HIT_5: 'audio/asteroid-hit-5.flac',
    ASTEROID_HIT_6: 'audio/asteroid-hit-6.flac',
    ASTEROID_HIT_7: 'audio/asteroid-hit-7.flac',
    ASTEROID_HIT_8: 'audio/asteroid-hit-8.flac',
    CRASH: 'audio/crash.flac',
};