.button{width: 100px !important;}
#outsidePanel .button{width: 115px !important;}
.eventPanel .button {width: 122px !important;}
.button .tooltip {width: 120px !important;}
#workers {width: 180px !important;}
#hullRow {width: 90px !important;}
#engineRow {width: 90px !important;}