(function(){
	//only used for poedit to find translatable strings
	var keywords = [ 
		_('saved.'),
		_('wood'),
		_('builder'),
		_('teeth'),
		_('meat'),
		_('fur'),
		_('alien alloy'),
		_('bullets'),
		_('charm'),
		_('leather'),
		_('iron'),
		_('steel'),
		_('coal'),
		_('sulphur'),
		_('energy cell'),
		_('torch'),
		_('medicine'),
		_('hunter'),
		_('trapper'),
		_('tanner'),
		_('grenade'),
		_('bolas'),
		_('bayonet'),
		_('charcutier'),
		_('iron miner'),
		_('iron mine'),
		_('coal miner'),
		_('coal mine'),
		_('sulphur miner'),
		_('sulphur mine'),
		_('armourer'),
		_('steelworker'),
		_('bait'),
		_('cured meat'),
		_('scales'),
		_('compass'),
		_('laser rifle'),
		_('gatherer'),
		_('cloth'),
		_('scales'),
		_('cured meat'),
		_('thieves'),
		_('not enough fur'),
		_('not enough wood'),
		_('not enough coal'),
		_('not enough iron'),
		_('not enough steel'),
		_('not enough sulphur'),
		_('baited trap'),
		_('not enough scales'),
		_('not enough cloth'),
		_('not enough teeth'),
		_('not enough leather'),
		_('not enough meat'),
		_('the compass points east'),
		_('the compass points west'),
		_('the compass points north'),
		_('the compass points south'),
		_('the compass points northeast'),
		_('the compass points northwest'),
		_('the compass points southeast'),
		_('the compass points southwest')
	]; 

	keywords = null;
})();
